# wxkit

A python library for collecting weather data and exposing API.

## Providers

1. [OpenWeather](https://openweathermap.org/api)

2. [Windy](https://api.windy.com)

3. [AccuWeather](https://developer.accuweather.com)
